from typing import overload
import rosbag2_py._compression_options
import rosbag2_py._storage

class SequentialCompressionWriter:
    def __init__(self, arg0: rosbag2_py._compression_options.CompressionOptions) -> None: ...
    def create_topic(self, arg0: rosbag2_py._storage.TopicMetadata) -> None: ...
    def open(self, arg0: rosbag2_py._storage.StorageOptions, arg1: rosbag2_py._storage.ConverterOptions) -> None: ...
    def remove_topic(self, arg0: rosbag2_py._storage.TopicMetadata) -> None: ...
    def split_bagfile(self) -> None: ...
    def take_snapshot(self) -> bool: ...
    @overload
    def write(self, arg0: str, arg1: str, arg2: int) -> None: ...
    @overload
    def write(self, arg0: str, arg1: str, arg2: int, arg3: int) -> None: ...

class SequentialWriter:
    def __init__(self) -> None: ...
    def close(self) -> None: ...
    def create_topic(self, arg0: rosbag2_py._storage.TopicMetadata) -> None: ...
    def open(self, arg0: rosbag2_py._storage.StorageOptions, arg1: rosbag2_py._storage.ConverterOptions) -> None: ...
    def remove_topic(self, arg0: rosbag2_py._storage.TopicMetadata) -> None: ...
    def split_bagfile(self) -> None: ...
    def take_snapshot(self) -> bool: ...
    @overload
    def write(self, arg0: str, arg1: str, arg2: int) -> None: ...
    @overload
    def write(self, arg0: str, arg1: str, arg2: int, arg3: int) -> None: ...

def get_registered_compressors() -> Set[str]: ...
def get_registered_serializers() -> Set[str]: ...
def get_registered_writers() -> Set[str]: ...



import rosbag2_py._storage

class Info:
    def __init__(self) -> None: ...
    def read_metadata(self, arg0: str, arg1: str) -> rosbag2_py._storage.BagMetadata: ...
    def read_metadata_and_output_service_verbose(self, arg0: str, arg1: str) -> None: ...



from typing import Any

class SequentialCompressionReader:
    def __init__(self) -> None: ...
    def get_all_message_definitions(self, *args, **kwargs) -> Any: ...
    def get_all_topics_and_types(self, *args, **kwargs) -> Any: ...
    def get_metadata(self, *args, **kwargs) -> Any: ...
    def has_next(self) -> bool: ...
    def open(self, arg0, arg1) -> None: ...
    def open_uri(self, arg0: str) -> None: ...
    def read_next(self) -> tuple: ...
    def reset_filter(self) -> None: ...
    def seek(self, arg0: int) -> None: ...
    def set_filter(self, arg0) -> None: ...
    def set_read_order(self, arg0) -> bool: ...

class SequentialReader:
    def __init__(self) -> None: ...
    def get_all_message_definitions(self, *args, **kwargs) -> Any: ...
    def get_all_topics_and_types(self, *args, **kwargs) -> Any: ...
    def get_metadata(self, *args, **kwargs) -> Any: ...
    def has_next(self) -> bool: ...
    def open(self, arg0, arg1) -> None: ...
    def open_uri(self, arg0: str) -> None: ...
    def read_next(self) -> tuple: ...
    def reset_filter(self) -> None: ...
    def seek(self, arg0: int) -> None: ...
    def set_filter(self, arg0) -> None: ...
    def set_read_order(self, arg0) -> bool: ...

def get_registered_readers() -> Set[str]: ...



from typing import ClassVar

FILE: CompressionMode
MESSAGE: CompressionMode
NONE: CompressionMode

class CompressionMode:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    FILE: ClassVar[CompressionMode] = ...
    MESSAGE: ClassVar[CompressionMode] = ...
    NONE: ClassVar[CompressionMode] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class CompressionOptions:
    compression_format: str
    compression_mode: CompressionMode
    compression_queue_size: int
    compression_threads: int
    def __init__(self, compression_format: str = ..., compression_mode: CompressionMode = ..., compression_queue_size: int = ..., compression_threads: int = ...) -> None: ...

def compression_mode_from_string(arg0: str) -> CompressionMode: ...
def compression_mode_to_string(arg0: CompressionMode) -> str: ...



from rosbag2_py._compression_options import CompressionMode as CompressionMode, CompressionOptions as CompressionOptions, compression_mode_from_string as compression_mode_from_string, compression_mode_to_string as compression_mode_to_string
from rosbag2_py._info import Info as Info
from rosbag2_py._reader import SequentialCompressionReader as SequentialCompressionReader, SequentialReader as SequentialReader, get_registered_readers as get_registered_readers
from rosbag2_py._reindexer import Reindexer as Reindexer
from rosbag2_py._storage import BagMetadata as BagMetadata, ConverterOptions as ConverterOptions, FileInformation as FileInformation, MessageDefinition as MessageDefinition, MetadataIo as MetadataIo, ReadOrder as ReadOrder, ReadOrderSortBy as ReadOrderSortBy, StorageFilter as StorageFilter, StorageOptions as StorageOptions, TopicInformation as TopicInformation, TopicMetadata as TopicMetadata, get_default_storage_id as get_default_storage_id
from rosbag2_py._transport import PlayOptions as PlayOptions, Player as Player, RecordOptions as RecordOptions, Recorder as Recorder, ServiceRequestsSource as ServiceRequestsSource, bag_rewrite as bag_rewrite
from rosbag2_py._writer import SequentialCompressionWriter as SequentialCompressionWriter, SequentialWriter as SequentialWriter, get_registered_compressors as get_registered_compressors, get_registered_serializers as get_registered_serializers, get_registered_writers as get_registered_writers



from typing import Any, ClassVar, List

import datetime
import rosbag2_py._storage

class PlayOptions:
    clock_publish_frequency: float
    clock_publish_on_topic_publish: bool
    clock_topics: List[str]
    delay: float
    disable_keyboard_controls: bool
    disable_loan_message: bool
    exclude_regex_to_filter: str
    exclude_service_events_to_filter: List[str]
    exclude_topics_to_filter: List[str]
    loop: bool
    node_prefix: str
    playback_duration: float
    playback_until_timestamp: int
    publish_service_requests: bool
    rate: float
    read_ahead_queue_size: int
    regex_to_filter: str
    service_requests_source: Any
    services_to_filter: List[str]
    start_offset: float
    start_paused: bool
    topic_qos_profile_overrides: dict
    topic_remapping_options: List[str]
    topics_to_filter: List[str]
    wait_acked_timeout: int
    def __init__(self) -> None: ...

class Player:
    def __init__(self) -> None: ...
    def burst(self, storage_options: rosbag2_py._storage.StorageOptions, play_options: PlayOptions, num_messages: int) -> None: ...
    def cancel(self, *args, **kwargs) -> Any: ...
    def play(self, storage_options: rosbag2_py._storage.StorageOptions, play_options: PlayOptions) -> None: ...

class RecordOptions:
    all_services: bool
    all_topics: bool
    compression_format: str
    compression_mode: str
    compression_queue_size: int
    compression_threads: int
    disable_keyboard_controls: bool
    exclude_regex: str
    exclude_service_events: List[str]
    exclude_topic_types: List[str]
    exclude_topics: List[str]
    ignore_leaf_topics: bool
    include_hidden_topics: bool
    include_unpublished_topics: bool
    is_discovery_disabled: bool
    node_prefix: str
    regex: str
    rmw_serialization_format: str
    services: List[str]
    start_paused: bool
    topic_polling_interval: datetime.timedelta
    topic_qos_profile_overrides: dict
    topic_types: List[str]
    topics: List[str]
    use_sim_time: bool
    def __init__(self) -> None: ...

class Recorder:
    def __init__(self) -> None: ...
    def cancel(self, *args, **kwargs) -> Any: ...
    def record(self, storage_options: rosbag2_py._storage.StorageOptions, record_options: RecordOptions, node_name: str = ...) -> None: ...

class ServiceRequestsSource:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    CLIENT_INTROSPECTION: ClassVar[ServiceRequestsSource] = ...
    SERVICE_INTROSPECTION: ClassVar[ServiceRequestsSource] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

def bag_rewrite(arg0: List[rosbag2_py._storage.StorageOptions], arg1: str) -> None: ...
